//Copyright (c) 2015 Artur Smaroń
//
//Permission is hereby granted, free of charge, to any person obtaining a copy
//of this software and associated documentation files (the "Software"), to deal
//in the Software without restriction, including without limitation the rights
//to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//copies of the Software, and to permit persons to whom the Software is
//furnished to do so, subject to the following conditions:
//
//
//The above copyright notice and this permission notice shall be included in
//all copies or substantial portions of the Software.
//
//
//THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
//AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//THE SOFTWARE.




var selectedMenuComponent = -1;
var selectedElementId = 0;
var MouseIsDown = 0;
var PreviousMousePosX = 0;
var PreviousMousePosY = 0;

var waitingForLink = "false";
var firstToLink;
var SecondToLink;

var inputRDFContent = null;
var outputRDFContent = null;

var ovalObjects = {};
var squareObjects = {};
var blankObjects = {};
var linkObjects = {};


var ovalObjectsTags = {};
var blankObjectsTags = {};
//var linkObjectsTags = {};


var paperTranslation_X = 0,paperTranslation_Y = 0;

var rdfScale = 1;
var linkJustRemoved;
var graph = new joint.dia.Graph;
var rdfType = 'none';



function getTextWidth(text, font, mode) {
    // re-use canvas object for better performance
    var canvas = getTextWidth.canvas || (getTextWidth.canvas = document.createElement("canvas"));
    var context = canvas.getContext("2d");
    context.font = font;
    var metrics = context.measureText(text);
	var width = metrics.width;
	switch(mode)
	{
		case 1: 
			width *= 1.45;
		break;
		case 2: 
			width *= 1.55;
		break;
		case 3:
			width *= 1.55;
			if(width < 200)
			{
				width = 200;
			}
		break;
	}
	if(width < 100)
	{
		width = 100;
	}
    return width;
}

function calculateNodeSize(label) {

    var maxLineLength = _.max(label.split('\n'), function(l) {
        return l.length;
    }).length;
    var letterSize = 14;
    var width = 1 * (letterSize * (0.5 * maxLineLength + 1));
	
	if(width < 100)
	{
		width = 100;
	}

    return width;
}

function makeOvalObject(label) {
	var nodeSize = getTextWidth(label, "14 arial", 2);
    var cell = new joint.shapes.rdf.OvalObject({
                        position: { x: 0, y: 0},
						size: {width: nodeSize + 10, height: 60},
                        attrs: {
                            '.text_value': { text: label },
							'.root': {rx: nodeSize / 2},
							'.selectionSquare': {width: nodeSize + 11},
							'.selectionFrame': {display: 'none'}
                        }
                    });	
	return cell;
}
function makeSquareObject(label) {

	var nodeSize = getTextWidth(label, "14 arial", 1);
    var cell = new joint.shapes.rdf.SquereObject({
                        position: { x: 0, y: 0},
                        attrs: {
                            '.text_value': { text: label },
							'.root': {width: nodeSize},
							'.selectionSquare': {width: nodeSize + 14},
							'.selectionFrame': {display: 'none'}
                        }
                    });
	return cell;
}
function makeBlankObject(label) {

	var nodeSize = getTextWidth(label, "14 arial", 2);
    var cell = new joint.shapes.rdf.BlankObject({
                        position: { x: 0, y: 0},
						size: {width: nodeSize + 10, height: 60},
                        attrs: {
                            '.text_value': { text: label },
							'.root': {rx: nodeSize / 2},
							'.selectionSquare': {width: nodeSize + 11},
							'.selectionFrame': {display: 'none'}
                        }
                    });	
	return cell;					
}
function makeLinkObject(label, srcId, dstId) {
    var cell = new joint.shapes.rdf.UriArrow({
                        source: { id: srcId },
						target: { id: dstId },
						attrs: {
							'.selectionFrame': {display: 'none'}
                        },
						labels: [
							{ attrs: { text: { text: label} }}
						]
                    });
	return cell;					
}

function getClickPosition(e) {
    var xPosition = e.clientX;
    var yPosition = e.clientY;
	return xPosition;
}
function allowDrop(ev) {
    ev.preventDefault();
}
function drop(ev) {
    //ev.preventDefault();
    //var data = ev.dataTransfer.getData("text");
    //ev.target.appendChild(document.getElementById(data));
	
	ev.preventDefault();
	//var element = document.getElementById("paper");
    var X = (ev.layerX - $(ev.target).position().left - paperTranslation_X) * (1/rdfScale);
	var Y = (ev.layerY - $(ev.target).position().top - paperTranslation_Y) * (1/rdfScale);
	var cell = null;
	switch(rdfType)
	{
		case 'uriobject_type': 
		{
			cell = new joint.shapes.rdf.OvalObject({
                        position: { x: X, y: Y},
                        attrs: {
                            '.text_value': { text: "" }
                        }
                    });
					ovalObjects[cell.id] = cell;
                    graph.addCell(cell);
                    if (selectedElementId !== 0) {
                        var lastCell = graph.getCell(selectedElementId);
                        lastCell.attr('.selectionFrame/display', 'none');
                    }
                    selectedElementId = cell.id;
		}
		
		break;
		case 'literal_type': 
		{
			cell = new joint.shapes.rdf.SquereObject({
                        position: { x: X - 50, y: Y - 25},
                        attrs: {
                            '.text_value': { text: "" }
                        }
                    });
					squareObjects[cell.id] = cell;
                    graph.addCell(cell);
                    if (selectedElementId !== 0) {
                        var lastCell = graph.getCell(selectedElementId);
                        lastCell.attr('.selectionFrame/display', 'none');
                    }
                    selectedElementId = cell.id;
		}
		break;
		case 'genid_type': 
		{
			cell = new joint.shapes.rdf.BlankObject({
                        position: { x: X, y: Y },
                        attrs: {
                            '.text_value': { text: "" }
                        }
                    });
					blankObjects[cell.id] = cell;
                    graph.addCell(cell);
                    if (selectedElementId !== 0) {
                        var lastCell = graph.getCell(selectedElementId);
                        lastCell.attr('.selectionFrame/display', 'none');
                    }
                    selectedElementId = cell.id;
		}
		
		break;
		case 'uriarrow_type': 
		{
			cell = new joint.shapes.rdf.UriArrow({
                        source: { x: X - 100, y: Y },
						target: { x: X + 100, y: Y },
						attrs: {
							'.selectionSquare': { x: X - 110,  y: Y -10, width: 220, height: 20}
						},
						labels: [
							{ attrs: { text: { text: ''} }}
						]
                    });
					linkObjects[cell.id] = cell;
                    graph.addCell(cell);
                    if (selectedElementId !== 0) {
                        var lastCell = graph.getCell(selectedElementId);
                        lastCell.attr('.selectionFrame/display', 'none');
                    }
                    selectedElementId = cell.id;
		}
		break;
	}
	$("#deleteSelectedBtn").removeAttr('disabled');
	$("#deleteSelectedBtn").removeClass('delete_nonactiveIcon');
	$("#deleteSelectedBtn").addClass('deleteIcon');
	
	if(cell != null)
	{
			var type = cell.get('type');
			switch(type)
			{
				case 'rdf.SquereObject':
				{
					$("#literalObjAttr").show();
				
					$("#literalObjVal").val(cell.attr('.text_value/text'));
					$("#literalObjType").val(cell.get('rdftype'));

					$("#ovalObjAttr").hide();
					$("#blankObjAttr").hide();
					$("#linkObjAttr").hide();
					
				}break;
				case 'rdf.OvalObject':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").show();
					$("#ovalObjUri").val(cell.attr('.text_value/text'));
					$("#blankObjAttr").hide();
					$("#linkObjAttr").hide();
				}break;
				case 'rdf.BlankObject':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").hide();
					$("#blankObjAttr").show();
					$("#blankObjUri").val(cell.attr('.text_value/text'));
					$("#linkObjAttr").hide();
				}break;
				case 'rdf.UriArrow':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").hide();
					$("#blankObjAttr").hide();
					$("#linkObjAttr").show();
					$("#linkObjUri").val(cell.get('labels')[0]['attrs']['text']['text']);
				}break;
			
			}
	}
	
}
function drag(ev) {
    rdfType = ev.target.id;
}	

$(document).ready(function () {

var fileInput = document.getElementById('fileInput');
fileInput.addEventListener('change', function (e) {
        var file = fileInput.files[0];
        var textType = /text.*/;

        
        var reader = new FileReader();

        reader.onload = function (e) {
		$("#loadingIndicator").css("display","");
            inputRDFContent = reader.result;
			
            selectedElementId = 0;

            graph.clear();

			
			ovalObjects = {};
			squareObjects = {};
			blankObjects = {};
			linkObjects = {};
			ovalObjectsTags = {};
			blankObjectsTags = {};
			
			var cells = [];
			var extremal_x = 3000;
				var extremal_y = 1200;
			var pos = 0;
            var instructions = inputRDFContent.split(/\r|\r\n|\n/);
			
            var oval = JSON.parse(instructions[0]);
			var square = JSON.parse(instructions[1]);
			var blank = JSON.parse(instructions[2]);
			var link = JSON.parse(instructions[3]);
			
            _.each(oval, function (elem) {
				//elem['attrs'][".selectionFrame"]["display"] = "";
				var newCell = new joint.shapes.rdf.OvalObject(elem)
				ovalObjects[newCell.id] = newCell;
				pos = newCell.get('position');
				if(pos.x > extremal_x)
				{
					extremal_x = pos.x;
				}
				if(pos.y > extremal_y)
				{
					extremal_y = pos.y;
				}
				cells.push(newCell);
				//graph.addCell(newCell);
				ovalObjectsTags[newCell.attr('.text_value/text')] = newCell.id;
				//newCell.attr('.selectionFrame/display', 'none');
            });
			_.each(square, function (elem) {
				//elem['attrs'][".selectionFrame"]["display"] = "";
                var newCell = new joint.shapes.rdf.SquereObject(elem);
				squareObjects[newCell.id] = newCell;
				if(pos.x > extremal_x)
				{
					extremal_x = pos.x;
				}
				if(pos.y > extremal_y)
				{
					extremal_y = pos.y;
				}
				cells.push(newCell);
				//graph.addCell(newCell);
				//newCell.attr('.selectionFrame/display', 'none');
            });
			_.each(blank, function (elem) {
				//elem['attrs'][".selectionFrame"]["display"] = "";
                var newCell = new joint.shapes.rdf.BlankObject(elem);
				blankObjects[newCell.id] = newCell;
				if(pos.x > extremal_x)
				{
					extremal_x = pos.x;
				}
				if(pos.y > extremal_y)
				{
					extremal_y = pos.y;
				}
				cells.push(newCell);
				//graph.addCell(newCell);
				blankObjectsTags[newCell.attr('.text_value/text')] = newCell.id;
				//newCell.attr('.selectionFrame/display', 'none');
            });
			_.each(link, function (elem) {
				//elem['attrs'][".selectionFrame"]["display"] = "";
                var newCell = new joint.shapes.rdf.UriArrow(elem);
				linkObjects[newCell.id] = newCell;
				cells.push(newCell);
				//graph.addCell(newCell);
				//newCell.attr('.selectionFrame/display', 'none');
            });
			
				$("#mainContainer").css('width', extremal_x + 300);
				$("#mainContainer").css('height', extremal_y + 300);
			
			
			
			graph.addCells(cells);
			
        }
        reader.readAsText(file); 
    });

$(".ui-t").click(function() {
        $('.ui-tooltip').remove();

    });

	

$("#triplesToRdfForm").validate({
			debug: false,
			rules: {
				triplesData: "required"
				
			},
			messages: {
				triplesData: "asdf",
			},
			submitHandler: function(form) {
				$.post('SemWeb/examples/converter_2.php', $("#triplesToRdfForm").serialize(), function(data) {
				
				var fatalError = data.substring(1, 6);
				if(fatalError === 'Fatal')
				{
					$("#errorInfo").text(data);
					$("#errorInformationDiv").dialog("open");
					return;
				}
				
				var textArea = document.createElement('textarea');
				textArea.value = data;
				if (textArea.value != '') {
					var blob = new Blob([textArea.value], { type: "text/plain;charset=" + document.characterSet });
					saveAs(blob, $("#text_filename").val() + '.rdf');
				}
				//var myHTMLOutput = '<h2>RDF/XML of the Data Model</h2>';

				//myHTMLOutput += data;
				//$('#test').val(myHTMLOutput);
				console.log('Saved!');
				
				});
				
			}
		});	
	
	
	
$("#myform").validate({
			debug: false,
			rules: {
				rdfData: "required",
                option: "required"
				
			},
			messages: {
				rdfData: "Please enter RDF content...",
			},
			submitHandler: function(form) {
				$.post('SemWeb/examples/converter.php', $("#myform").serialize(), function(data) {
				var fatalError = data.substring(1, 6);
				if(fatalError === 'Fatal')
				{
					$("#errorInfo").text(data);
					$("#errorInformationDiv").dialog("open");
                     
					return;
				}
				$("#loadingIndicator").css("display","");
				
                    
                   
                    
				var res = data.replace(/\\/g, '');
				var result = '';
				var r = '';
                  
                var arr = '';
                try{
                    arr=JSON.parse(res);
                }catch(e){
                    $("#loadingIndicator").css("display","none");
                    alert("Some error!");
                }
                    

				//res += data[0];
				var ilosc = 0;
				
				ovalObjects = {};
				squareObjects = {};
				blankObjects = {};
				linkObjects = {};

//makeOvalObject
//makeSquareObject
//makeBlankObject
//makeLinkObject
				ovalObjectsTags = {};
				blankObjectsTags = {};
				//linkObjectsTags = {};
				
				
				selectedElementId = 0;
				graph.clear();
				
				var rankSep = 200;
				var test = 0;
				var src = 0, dst = 0;
				
				
				
				var myHTMLOutput = '<h2>Triples of the Data Model</h2>';
				myHTMLOutput += '<table width="100%" border="1" cellpadding="0" cellspacing="0" style="font-size:12">';
				myHTMLOutput += '<th>Number</th><th>Subject</th><th>Predicate</th><th>Object</th>';
				
				for(a in arr)
				{
					for(b in arr[a])
					{
						for(c in arr[a][b])
						{
							var datatype = arr[a][b][c].datatype;
							if(datatype === undefined)
							{
								datatype = '';
							}
							else
							{
								datatype = '^^' + arr[a][b][c].datatype;
							}
							
							var subj, predic, obj;
							if(a.charAt(0) === '_' && a.charAt(1) === ':')
							{
								if(blankObjectsTags[a] === undefined)
								{
									subj = makeBlankObject(a);
									blankObjectsTags[a] = subj.id;
									blankObjects[subj.id] = subj;
								}
								else
								{
									subj = blankObjects[blankObjectsTags[a]];
								}
							}
							else
							{
								if(ovalObjectsTags[a] === undefined)
								{
									subj = makeOvalObject(a);
									ovalObjectsTags[a] = subj.id;
									ovalObjects[subj.id] = subj;
								}
								else
								{
									subj = ovalObjects[ovalObjectsTags[a]];
								}
								
							}
							
							
							switch(arr[a][b][c].type)
							{
								case 'literal':
								{
									obj = makeSquareObject(arr[a][b][c].value);
									if(datatype === '')
									{
										obj.set('rdftype', '');
									}
									else
									{
										obj.set('rdftype', arr[a][b][c].datatype);
									}
									squareObjects[obj.id] = obj;
								}break;
								case 'bnode':
								{
									if(blankObjectsTags[arr[a][b][c].value] === undefined)
									{
										obj = makeBlankObject(arr[a][b][c].value);
										blankObjectsTags[arr[a][b][c].value] = obj.id;
										blankObjects[obj.id] = obj;
									}
									else
									{
										obj = blankObjects[blankObjectsTags[arr[a][b][c].value]];
									}
									
								}break;
								case 'uri':
								{
									if(ovalObjectsTags[arr[a][b][c].value] === undefined)
									{
										obj = makeOvalObject(arr[a][b][c].value);
										ovalObjectsTags[arr[a][b][c].value] = obj.id;
										ovalObjects[obj.id] = obj;
									}
									else
									{
										obj = ovalObjects[ovalObjectsTags[arr[a][b][c].value]];
									}
								}break;
							}
							
							predic = makeLinkObject(b, subj.id, obj.id);
							//linkObjectsTags[b] = predic.id;
							linkObjects[predic.id] = predic;
							
							test = getTextWidth(b, "14 arial", 3);
							if(test > rankSep)
							{
								rankSep = Number(test);
								src = subj.id;
								dst = obj.id;
							}
							
							//graph.addCell(subj);
							//graph.addCell(obj);
							//graph.addCell(predic);
							
								ilosc++;
								result += '<tr>';
								result += '<td>' + ilosc + '</td>';
								result += '<td>' + a + '</td>';
								result += '<td>' + b + '</td>';
								result += '<td>' + arr[a][b][c].value + datatype + '</td>';
								result += '</tr>';
								
								//r += ilosc + '***' + a + '.....' +  b + '.....' + arr[a][b][c].type + '.....' + arr[a][b][c].value + '.....' + datatype +  '\n';
								
							}
							//console.log(a[0] + '\n');
					}
					
				}
				//console.log(r + '\n');
				var c1 = [];
				_.each(ovalObjects, function(c) {
					c1.push(c);
				});
				//graph.addCells(c1);
				var c2 = [];
				_.each(squareObjects, function(c) {
					c1.push(c);
				});
				//graph.addCells(c2);
				var c3 = [];
				_.each(blankObjects, function(c) {
					c1.push(c);
				});
				//graph.addCells(c3);
				var c4 = [];
				_.each(linkObjects, function(c) {
					c1.push(c);
					//c4.push(c);
				});
				
				graph.addCells(c1);
				//graph.addCells(ovalObjects);
				//graph.addCells(squareObjects);
				//graph.addCells(blankObjects);
				//graph.addCells(linkObjects);
				console.log(c1.length);
				
				
				
		
		if(src !== 0 && dst !== 0)
		{
			src = graph.getCell(src);
			dst = graph.getCell(dst);
			if((src.get('type') === 'rdf.BlankObject' || src.get('type') === 'rdf.OvalObject') && (dst.get('type') === 'rdf.BlankObject' || dst.get('type') === 'rdf.OvalObject'))
			{
				//rankSep += (src.attr('.root/rx') + dst.attr('.root/rx')) / 2;
				//rankSep += 100;
			}
		}

		joint.layout.DirectedGraph.layout(graph, { setLinkVertices: false, rankDir: 'LR', rankSep: rankSep });
		console.log(rankSep);
var extremal_x = 3000;
				var extremal_y = 1200;

var elements = graph.getElements();
//console.log('2');
_.each(elements, function(elem) {
					var pos = elem.get('position');
					if(pos.x > extremal_x)
							{
								extremal_x = pos.x;
							}
							if(pos.y > extremal_y)
							{
								extremal_y = pos.y;
							}
				});
					//console.log('3');				
				
				$("#mainContainer").css('width', extremal_x + 300);
				$("#mainContainer").css('height', extremal_y + 300);
				//paper.height = extremal_y + 300;
				//console.log(extremal_x);
				myHTMLOutput += result;
				myHTMLOutput += '</table></br>';
				
				var ele = ' element';
				if(c1.length !== 1)
				{
					ele += 's';
				}
				myHTMLOutput += c1.length + ele;
				$('#results').html(myHTMLOutput);
				});
			}
		});
	

	
		$("#showHideRDFcontentTBx").click(function () {
        if($('#showHideRDFcontentTBx').prop('checked'))
		{
			$("#rdfData").html('<textarea class="lined" rows="15" name="rdfData" style="width: 100%;" placeholder="Enter RDF/XML content..."></textarea>');
			$("#rdfData").css('display', '');
			$("#clearRdfBtn").css('display', '');
			$("#submitBtn").css('display', '');

			$(".lined").linedtextarea(
				{selectedLine: 1}
			);
			
			
			
			
		}
		else
		{
			$("#rdfData").css('display', 'none');
			$("#rdfData").html('')
			$("#clearRdfBtn").css('display', 'none');
			$("#submitBtn").css('display', 'none');
		}
    });
    $("#taskAttributesDiv").hide();
    $('#attributesMenu').toggle();
    $(document).tooltip();
	//var scalledHeight = 1200;
    var paper = new joint.dia.Paper({
        el: $('#paper'),
        width: '100%',
        height: '100%',
        gridSize: 10,
        model: graph,
        perpendicularLinks: false,
		async: true
    });

    $("#zoomInBtn").click(function () {
        rdfScale *= 1.1;
		//scalledHeight *= 1.1;
        V(paper.viewport).scale(rdfScale);
		//V(paper.viewport).translate(-(rdfScale), -(rdfScale*1200 - 1200)/2);
		//console.log(paper.options.width);
    });
    $("#zoomOutBtn").click(function () {
        rdfScale *= 0.9;
        V(paper.viewport).scale(rdfScale);
    });
    $("#zoomNormalBtn").click(function () {
        rdfScale = 1.0;
        V(paper.viewport).scale(rdfScale);
    });

    $("#autoLayoutBtn").click(function () {
		if (selectedElementId !== 0) {
            var lastCell = graph.getCell(selectedElementId);
            lastCell.attr('.selectionFrame/display', 'none');
        }
        selectedElementId = 0;

		//TO DO
		//dezaktywacja funkcji
		//obliczyć rankSep na podstawie długości najdłuższego uri spośród linków
		var rankSep = 200;
        var test = 0;
		
		var src = 0, dst = 0;
		
		var links = graph.getLinks();
        _.each(links, function (link) {
			link.set('vertices', []);
			test = getTextWidth(link.get('labels')[0]['attrs']['text']['text'], "14 arial", 3);
			if(test > rankSep)
			{
				rankSep = Number(test);
				src = link.get('source').id;
				dst = link.get('target').id;
			}
		});
		if(src !== 0 && dst !== 0)
		{
			src = graph.getCell(src);
			dst = graph.getCell(dst);
			if((src.get('type') === 'rdf.BlankObject' || src.get('type') === 'rdf.OvalObject') && (dst.get('type') === 'rdf.BlankObject' || dst.get('type') === 'rdf.OvalObject'))
			{
				//rankSep += (src.attr('.root/rx') + dst.attr('.root/rx')) / 2;
			}
		}

		joint.layout.DirectedGraph.layout(graph, { setLinkVertices: false, rankDir: 'LR', rankSep: rankSep });
		$("#literalObjAttr").hide();
		$("#ovalObjAttr").hide();
		$("#blankObjAttr").hide();
		$("#linkObjAttr").hide();
        //_.each(tabele, function (node) {
        //    node.set('position', { x: node.get('position').x + posOfPaper_x, y: node.get('position').y + posOfPaper_y });
        //});
        //_.each(relations, function (r) {

        //    if (r.get('source').id == r.get('target').id) {
        //        var id = r.get('source').id;
        //        var pos;
        //        var obj = tabele[id];
        //        var middlePoint;
        //        for (k in tabele) {
        //            if (tabele[k].id == id) {
        //                pos = tabele[k].get('position');
        //                middlePoint = pos.x + tabele[k].get('size').width / 2;
        //                break;
        //            }
        //        }
        //        r.set('vertices', [{ x: (middlePoint - 10), y: (pos.y - 20) }, { x: (middlePoint + 10), y: (pos.y - 20) }]);

        //    }

        //});
    });
$("#readFileBtn").click(function () {
        $("#fileInput").click();
        

    });
$("#saveFileBtn").click(function () {


$("#savingInfo").text("Enter name and choose file format");
$("#text_filename").val('');
$("#saveFileDiv").dialog("open");

		
		
});
$("#clearAllBtn").click(function () {


$("#newModelInfoDiv").text("Clearing all data: are you sure?");
$("#newModelConfirm").dialog("open");

		
		
});
	
	
	$("#filtersChBx").click(function () {
        if($('#filtersChBx').prop('checked'))
		{
			$("#filterOptionsDiv").show();
		}
		else
		{
			$("#filterOptionsDiv").hide();
		}
		});
		
		
	$("input[name=filter]").click(function () {
	var mode = $("input[name=filter]:checked").val();
        if(mode === '1')
		{
			$("#partialFilter").attr('disabled', 'disabled');
			$("#wholeFilter").removeAttr('disabled');
		}
		else
		{
			$("#wholeFilter").attr('disabled', 'disabled');
			$("#partialFilter").removeAttr('disabled');
		}
		});
	$("#filterBtn").click(function () {
		selectedElementId = 0;
		$("#literalObjAttr").hide();
		$("#ovalObjAttr").hide();
		$("#blankObjAttr").hide();
		$("#linkObjAttr").hide();
	
	
			var fValue_1 = $("#wholeFilter").val();
			fValue_1 = fValue_1.split(';');
			//console.log(JSON.stringify(fValue_1));
			var fValue_2 = $("#partialFilter").val();
			fValue_2 = fValue_2.split(';');
			var mode = $("input[name=filter]:checked").val();
			
			if(mode === '1')
			{
			
			
						var ids = {};
				var elements = graph.getElements();
				var links = graph.getLinks();
				 
				 _.each(elements, function (elem) {
				 var p = false;
					_.each(fValue_1, function (c) {
						if(elem.attr('.text_value/text') === c)
						{
							p = true;
						}
					});
					if(p === true)
					{
						elem.attr('./visibility', 'hidden');
						ids[elem.id] = true;
					}
					else
					{
						elem.attr('./visibility', '');
					}
				 });
				 var sources = {};
				 var destinations = {};
				 _.each(links, function (link) {
				 
				 var src = graph.getCell(link.get('source').id);
				 var dst = graph.getCell(link.get('target').id);
				 
				 
				 if(ids[src.id] === true)
				 {
					link.attr('./visibility', 'hidden');
					return;
				 }
				 else
				 {
					link.attr('./visibility', '');
				 }
				 if(ids[dst.id] === true)
				 {
					link.attr('./visibility', 'hidden');
					return;
				 }
				 else
				 {
					link.attr('./visibility', '');
				 }
				 
				 var p = false;
					_.each(fValue_1, function (c) {
						if(link.get('labels')[0]['attrs']['text']['text'] === c)
						{
							p = true;
						}
					});
					if(p === true)
					{
						link.attr('./visibility', 'hidden');
					}
					else
					{
						link.attr('./visibility', '');
					}
				 });
			
			

			}
			else
			{
				var ids = {};
				var elements = graph.getElements();
				var links = graph.getLinks();
				// console.log(fValue_2);
				 _.each(elements, function (elem) {
				 var p = false;
					_.each(fValue_2, function (c) {
						if(c !== "" && (elem.attr('.text_value/text')).indexOf(c) != -1)
						{
							p = true;
						}
					});
					if(p === true)
					{
						elem.attr('./visibility', 'hidden');
						ids[elem.id] = true;
				 }
					else
					{
						elem.attr('./visibility', '');
					}
				 });
				 var sources = {};
				 var destinations = {};
				 _.each(links, function (link) {
				 
				 var src = graph.getCell(link.get('source').id);
				 var dst = graph.getCell(link.get('target').id);
				 
				 
				 if(ids[src.id] === true)
				 {
					link.attr('./visibility', 'hidden');
					return;
				 }
				 else
				 {
					link.attr('./visibility', '');
				 }
				 if(ids[dst.id] === true)
				 {
					link.attr('./visibility', 'hidden');
					return;
				 }
				 else
				 {
					link.attr('./visibility', '');
				 }
				 var p = false;
				 _.each(fValue_2, function (c) {
						if(c !== "" &&(link.get('labels')[0]['attrs']['text']['text']).indexOf(c) !== -1)
						{
							p = true;
						}
					});
					if(p === true)
					{
					link.attr('./visibility', 'hidden');
					}
					else
					{
						link.attr('./visibility', '');
					}
				 });
			}
		});
	
	
	
	$("#deleteSelectedBtn").click(function () {

$("#literalObjAttr").hide();
		$("#ovalObjAttr").hide();
		$("#blankObjAttr").hide();
		$("#linkObjAttr").hide();
if(ovalObjects[selectedElementId] !== undefined)
{
	delete ovalObjects[selectedElementId];
}
else if(squareObjects[selectedElementId] !== undefined)
{
	delete squareObjects[selectedElementId];
}
else if(blankObjects[selectedElementId] !== undefined)
{
	delete blankObjects[selectedElementId];
}
else
{
	delete linkObjects[selectedElementId];
}
	graph.getCell(selectedElementId).remove();
		selectedElementId = 0;
		//$("#taskAttributesDiv").hide();
		//$("#dataObjectDiv").hide();
		//$("#textAnnotationDiv").hide();
		$("#deleteSelectedBtn").attr('disabled', 'disabled');
		$("#deleteSelectedBtn").addClass('delete_nonactiveIcon');
		$("#deleteSelectedBtn").removeClass('deleteIcon');
	});
	
    $("#SaveCanvasDiv").hide();

    var canvas;
    var RdfSvg;
    $("#savePictureAsButton_SVG").click(function () {
        var textArea = document.createElement('textarea');
        textArea.value = RdfSvg;

        if (textArea.value != '') {
            var blob = new Blob([textArea.value], { type: "text/plain;charset=" + document.characterSet });
            saveAs(blob, $("#saveCanvasAsText").val() + '.svg');
        }

    });
    $("#savePictureAsButton_PNG").click(function () {

        canvas.toBlob(function (blob) {
            saveAs(blob, $("#saveCanvasAsText").val() + ".png");
        });

    });
    $("#deleteGeneratedPicture").click(function () {
        $("#SaveCanvasDiv").hide();
    });

    $("#generateImageBtn").click(function () {

        var x_min = 200000;
        var y_min = 200000;
        var x_max = -200000;
        var y_max = -200000;

        var objects = graph.getElements();

        _.each(objects, function (element) {

            var position = element.get('position');
            var size = element.get('size');
            var right_bottom_cornerX = position.x;
            var right_bottom_cornerY = position.y;

			right_bottom_cornerX += size.width;
			right_bottom_cornerY += size.height;
			
            if (x_min > position.x) {
                x_min = position.x;
            }
            if (y_min > position.y) {
                y_min = position.y;
            }
            if (x_max < right_bottom_cornerX) {
                x_max = right_bottom_cornerX;
            }
            if (y_max < right_bottom_cornerY) {
                y_max = right_bottom_cornerY;
            }
			if(element.get('type') === 'rdf.OvalObject' || element.get('type') === 'rdf.BlankObject')
			{
				x_min -= element.attr('.root/rx') / 2;
				y_min -= element.attr('.root/ry');
				x_max += element.attr('.root/rx') / 2;
				y_max += element.attr('.root/ry');
			}


        });
        var links = graph.getLinks();
        _.each(links, function (element) {

            var tableOfVertices = element.get('vertices');

			if(tableOfVertices !== undefined)
            {
			for (var i = 0; i < tableOfVertices.length; i++) {
                if (x_min > tableOfVertices[i].x) {
                    x_min = tableOfVertices[i].x;
                }
                if (y_min > tableOfVertices[i].y) {
                    y_min = tableOfVertices[i].y;
                }
                if (x_max < tableOfVertices[i].x) {
                    x_max = tableOfVertices[i].x;
                }
                if (y_max < tableOfVertices[i].y) {
                    y_max = tableOfVertices[i].y;
                }
            }
			}


        });
        x_min -= 10;
        y_min -= 10;

        var moveBy_x = x_min * rdfScale;
        var moveBy_y = y_min * rdfScale;

        var canvWidth = x_max - x_min + 30;
        canvWidth *= rdfScale;
        var canvHeight = y_max - y_min + 30;
        canvHeight *= rdfScale;


        var svgStringCont = '';
        var innerRdfSvg = document.getElementById('v-2');

        var svgContent_tables = innerRdfSvg.getElementsByClassName('element rdf');
        var svgContent_links = innerRdfSvg.getElementsByClassName('link');
        var serializer = new XMLSerializer();
        for (var i = 0; i < svgContent_tables.length; i++)
        { svgStringCont += serializer.serializeToString(svgContent_tables[i]); }
        for (var i = 0; i < svgContent_links.length; i++)
        { svgStringCont += serializer.serializeToString(svgContent_links[i]); }

        var svg2 = '<svg xmlns="http://www.w3.org/2000/svg" xlink="http://www.w3.org/1999/xlink"  style="background-color:white" version="1.1" width="' + (canvWidth - 10) + '" height="' + (canvHeight - 10) + '">' + '<g id="v_7" class="viewport" transform = "translate(' + (-moveBy_x) + ',' + (-moveBy_y) + ') scale(' + rdfScale + ',' + rdfScale + ')">' + svgStringCont + "</g>" + "</svg>";






        RdfSvg = svg2;

        canvas = document.createElement('canvas');
        canvas.id = "canvasss";

        canvas.nodeName = 'CANVAS',

        canvas.width = canvWidth;
        canvas.height = canvHeight;

        var ctx = canvas.getContext("2d");

        var DOMURL = self.URL || self.webkitURL || self;
        var img = new Image();
        var svg = new Blob([svg2], { type: "image/svg+xml;charset=utf-8" });

        var url = DOMURL.createObjectURL(svg);
        img.onload = function () {
            ctx.drawImage(img, 0, 0);
            DOMURL.revokeObjectURL(url);
        };
        var s = svg.size;
        img.src = url;

        $("#SaveCanvasDiv").show();
    });
    $("#fileInputFake").click(function () {
        $("#fileInput").click();


    });
    //..Dodać przyciski do html

    paper.on('cell:pointerdblclick',
        function (cellView, evt, x, y) {
            var cell = cellView.model;

        }
    );

    paper.on('cell:pointermove',
        function (cellView, evt, x, y) {
            var cell = cellView.model;
        });

    paper.on('cell:pointerdown',
        function (cellView, evt, x, y) {
            var cell = cellView.model;
            if (V(evt.target).hasClass('resizingPoint')) {

                cell.set('resizingMode', 1);
                cell.set('resizingPoint', { x: x, y: y });

            }
			var type = cell.get('type');
			switch(type)
			{
				case 'rdf.SquereObject':
				{
					$("#literalObjAttr").show();
				
					$("#literalObjVal").val(cell.attr('.text_value/text'));
					$("#literalObjType").val(cell.get('rdftype'));
					$("#ovalObjAttr").hide();
					$("#blankObjAttr").hide();
					$("#linkObjAttr").hide();
					
				}break;
				case 'rdf.OvalObject':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").show();
					$("#ovalObjUri").val(cell.attr('.text_value/text'));
					$("#blankObjAttr").hide();
					$("#linkObjAttr").hide();
				}break;
				case 'rdf.BlankObject':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").hide();
					$("#blankObjAttr").show();
					$("#blankObjUri").val(cell.attr('.text_value/text'));
					$("#linkObjAttr").hide();
				}break;
				case 'rdf.UriArrow':
				{
					$("#literalObjAttr").hide();

					$("#ovalObjAttr").hide();
					$("#blankObjAttr").hide();
					$("#linkObjAttr").show();
					$("#linkObjUri").val(cell.get('labels')[0]['attrs']['text']['text']);
					
					//console.log(JSON.stringify(cell));
				}break;
			
			}
            //if(cell instanceof joint.shapes.bpmn.Task)
            //{
                //$("#taskAttributesDiv").show();
            //}
            //else
            //{
                //$("#taskAttributesDiv").hide();
            //}


        });

    paper.on('cell:pointerup',
    function (cellView, evt, x, y) {
        var cell = cellView.model;

        pointerIsDown = false;


        if (selectedElementId !== 0) {
                var lastCell = graph.getCell(selectedElementId);
                lastCell.attr('.selectionFrame/display', 'none');
            }
        selectedElementId = cell.id;
        cell.attr('.selectionFrame/display', '');


		
		$("#deleteSelectedBtn").removeAttr('disabled');
		$("#deleteSelectedBtn").removeClass('delete_nonactiveIcon');
		$("#deleteSelectedBtn").addClass('deleteIcon');
		
        if (!(cell instanceof joint.shapes.rdf.UriArrow)) {
            if (selectedElementId !== 0) {
                var lastCell = graph.getCell(selectedElementId);
                lastCell.attr('.selectionFrame/display', 'none');
            }
            selectedElementId = cell.id;
            cell.attr('.selectionFrame/display', '');

            //$("#taskType").val(cell.get('taskType'));

        }
        else if (cell instanceof joint.shapes.rdf.UriArrow) {
            if (selectedElementId !== 0) {
                var lastCell = graph.getCell(selectedElementId);
                lastCell.attr('.selectionFrame/display', 'none');
            }
            selectedElementId = cell.id;
			
			
			
			
			var linkView = paper.findViewByModel(cell);
			
			var sourcePoint = linkView.getConnectionPoint('source', cell.get('source'), _.first(cell.get('vertices')) || cell.get('target'));
			var targetPoint = linkView.getConnectionPoint('target', cell.get('target'), _.last(cell.get('vertices')) || cell.get('target'));

			var x_1;
			var x_2;
			var y_1;
			var y_2;
			
			x_1 = sourcePoint['x'];
			y_1 = sourcePoint['y'];

			x_2 = targetPoint['x'];
			y_2 = targetPoint['y'];

			var X, Y;
			if(x_1 > x_2)
			{
				var temp = x_1;
				x_1 = x_2;
				x_2 = temp;
			}
			if(y_1 > y_2)
			{
				var temp = y_1;
				y_1 = y_2;
				y_2 = temp;
			}
			//var src = cell.get('source').id;
			//src = graph.getCell(src).attr('.text_value/text');
			//var dst = cell.get('target').id;
			//dst = graph.getCell(dst).attr('.text_value/text');
			//console.log("src: " + src + "; dst: " + dst);
			cell.attr({'.selectionSquare': {x: x_1 - 10, y: y_1 - 10, width: x_2 - x_1 + 20, height: y_2 - y_1 + 20},'.selectionFrame': {display: ''}});
        }
        else {

            selectedElementId = 0;
            //$("#usun").css('background-image', 'url("graphics/remove_wylaczony.png")');
        }

    });


    
    graph.on('remove', function (cell) {
		if (cell instanceof joint.shapes.rdf.UriArrow)
		{
			//delete linkObjectsTags[cell.get('labels')[0]['attrs']['text']['text']];
			delete linkObjects[cell.id];
		}
        
    });
paper.on('render:done',
        function() {
			var endTime = performance.now();
				$("#loadingIndicator").css("display","none");
        }
    );	

    paper.on('blank:pointerdown', function (evt, x, y) {
        MouseIsDown = 1;

        PreviousMousePosX = 0;
        PreviousMousePosY = 0;

		if(selectedElementId !== 0)
		{
			var lastCell = graph.getCell(selectedElementId);
			lastCell.attr('.selectionFrame/display', 'none');
		}
        selectedElementId = 0;
        $("#deleteSelectedBtn").attr('disabled', 'disabled');
		$("#deleteSelectedBtn").addClass('delete_nonactiveIcon');
		$("#deleteSelectedBtn").removeClass('deleteIcon');
		
		$("#literalObjAttr").hide();
		$("#ovalObjAttr").hide();
		$("#blankObjAttr").hide();
		$("#linkObjAttr").hide();
        
    });

    paper.on('blank:pointerdblclick', function (evt, x, y) {

    });

    //$(window).bind('beforeunload', function () {
        //return 'Are you sure You want to leave? \nMake sure You saved the model to file.';
    //});

    $("#paper").mousemove(function (event) {
        if (MouseIsDown === 1) {
            if (selectedElementId === 0) {

                var X = 0, Y = 0;
                if (PreviousMousePosX !== 0) {
                    X = event.clientX - PreviousMousePosX;
                }
                if (PreviousMousePosY) {
                    Y = event.clientY - PreviousMousePosY;
                }
				paperTranslation_X += X;
				paperTranslation_Y += Y;
                V(paper.viewport).translate(X, Y);

                PreviousMousePosX = event.clientX;
                PreviousMousePosY = event.clientY;

            }
        }

    });
    $("#paper").mouseup(function (event) {
        MouseIsDown = 0;
        PreviousMousePosX = 0;
        PreviousMousePosY = 0;

    });



    $("#button").click(function () {

        // Set the effect type
        var effect = 'slide';

        // Set the options for the effect type chosen
        var options = { direction: 'right' };

        // Set the duration (default: 400 milliseconds)
        var duration = 500;

        $('#myDiv').toggle(effect, options, duration);
    });
    var hiddenLeftMenu = 0;
    var hiddenRightMenu = 1;
    $("#shiftButtonMenuLeft").click(function () {
        var effect = 'slide';

        var options = { direction: 'left' };
        var duration = 150;

        $('#componentsMenu').toggle(effect, options, duration);
        if (hiddenLeftMenu === 1) {
            hiddenLeftMenu = 0;
            $("#shiftButtonMenuLeft").removeClass("shiftRightIcon");
            $("#shiftButtonMenuLeft").addClass("shiftLeftIcon");
            $("#leftMenuBar").removeClass("componentMenuCollapsed");
            $("#leftMenuBar").addClass("componentMenuExpanded");  
        }
        else
        {
            hiddenLeftMenu = 1;
            $("#shiftButtonMenuLeft").removeClass("shiftLeftIcon");
            $("#shiftButtonMenuLeft").addClass("shiftRightIcon");
            $("#leftMenuBar").removeClass("componentMenuExpanded");
            $("#leftMenuBar").addClass("componentMenuCollapsed");
        }
    });
	
	$("#okOvalObjBtn").click(function () {
		var textValue = $("#ovalObjUri").val();
		if(textValue === '')
		{
			$("#alertInfoDiv").text("URI cannot be epmty!");
			$("#dialog-confirm").dialog("open");
			return;
		}
		var cell = graph.getCell(selectedElementId);
		if(ovalObjectsTags[textValue] !== undefined && cell.attr('.text_value/text') != textValue)
		{
			$("#alertInfoDiv").text("Same URI already exists. Choose another one.");
			$("#dialog-confirm").dialog("open");
			return;
		}
		else
		{
			var nodeSize = getTextWidth(textValue, "14 arial", 2);
			
			cell.attr('.root/rx', nodeSize / 2);
			cell.set('size', {width: nodeSize + 10, height: cell.get('size').height });
			cell.attr('.selectionSquare/width', nodeSize + 11);
			delete ovalObjectsTags[cell.attr('.text_value/text')];
			cell.attr('.text_value/text', textValue);
			ovalObjectsTags[textValue] = cell.id;
		}
		
    });
	
	$("#okBlankObjBtn").click(function () {
		var textValue = $("#blankObjUri").val();
		if(textValue === '')
		{
			$("#alertInfoDiv").text("GENID cannot be epmty!");
			$("#dialog-confirm").dialog("open");
			return;
		}
		var cell = graph.getCell(selectedElementId);
		if(blankObjectsTags[textValue] !== undefined && cell.attr('.text_value/text') != textValue)
		{
			$("#alertInfoDiv").text("Same GENID already exists. Choose another one.");
			$("#dialog-confirm").dialog("open");
			return;
		}
		else
		{
			var nodeSize = getTextWidth(textValue, "14 arial", 2);

			cell.attr('.root/rx', nodeSize / 2);
			cell.set('size', {width: nodeSize + 10, height: cell.get('size').height });
			cell.attr('.selectionSquare/width', nodeSize + 11);
			delete blankObjectsTags[cell.attr('.text_value/text')];
			
			cell.attr('.text_value/text', textValue);
			blankObjectsTags[textValue] = cell.id;
		} 
    });
	
	$("#okLiteralObjBtn").click(function () {
	
		var textValue = $("#literalObjVal").val();
		if(textValue === '')
		{
			$("#alertInfoDiv").text("Literal cannot be epmty!");
			$("#dialog-confirm").dialog("open");
			return;
		}
		var textValue = $("#literalObjVal").val();
		var nodeSize = getTextWidth(textValue, "14 arial", 1);
		var cell = graph.getCell(selectedElementId);
        cell.attr('.text_value/text', textValue);
		cell.set('rdftype',$("#literalObjType").val());
		
		cell.attr('.root/width', nodeSize);
		cell.attr('.selectionSquare/width', nodeSize + 14);
    });
	
	$("#okLinkObjBtn").click(function () {
		
		var textValue = $("#linkObjUri").val();
		if(textValue === '')
		{
			$("#alertInfoDiv").text("Literal cannot be epmty!");
			$("#dialog-confirm").dialog("open");
			return;
		}
		
		//if(linkObjectsTags[textValue] !== undefined)
		//{
			//$("#alertInfoDiv").text("Same URI already exists. Choose another one.");
			//$("#dialog-confirm").dialog("open");
			//return;
		//}
		//else
		//{
			var cell = graph.getCell(selectedElementId);
			//delete linkObjectsTags[cell.get('labels')[0]['attrs']['text']['text']];
			cell.label(0, { attrs: { text: { text: $("#linkObjUri").val()} }});
			//linkObjectsTags[textValue] = cell.id;
		//}
		
		
		//cell.attr('.root/width', nodeSize);
		//cell.attr('.selectionSquare/width', nodeSize + 14);
		
        
		//var targetPoint = linkView.getConnectionPoint('target', cell.get('target'), _.last(cell.get('vertices')) || cell.get('target'));
		
		//cell.set('target', {x:, y: targetPoint['y']});
		//source: { x: X - 100, y: Y },
		//target: { x: X + 100, y: Y },
    });
	
	$("#dialog-confirm").dialog({
        autoOpen: false,
        resizable: false,
        width: 400,
        modal: true,
        buttons: {
            'OK': function() {
                $(this).dialog("close");

            }
        }
    });
	
	
	$("#errorInformationDiv").dialog({
        autoOpen: false,
        resizable: false,
        width: 700,
        modal: true,
        buttons: {
            'OK': function() {
                $(this).dialog("close");

            }
        }
    });
	
	$("#newModelConfirm").dialog({
        autoOpen: false,
        resizable: false,
        width: 400,
        modal: true,
        buttons: {
            'OK': function() {
				selectedElementId = 0;

				graph.clear();

			
			ovalObjects = {};
			squareObjects = {};
			blankObjects = {};
			linkObjects = {};
			ovalObjectsTags = {};
			blankObjectsTags = {};
			$("#literalObjAttr").hide();
		$("#ovalObjAttr").hide();
		$("#blankObjAttr").hide();
		$("#linkObjAttr").hide();
			$("#results").html('');
			$("#mainContainer").css('width', 3000);
				$("#mainContainer").css('height', 1200);
			
			
			
			
                $(this).dialog("close");

            },
			'Cancel': function() {
                $(this).dialog("close");

            }
        }
    });
	
	$("#saveFileDiv").dialog({
        autoOpen: false,
        resizable: false,
        width: 400,
        modal: true,
        buttons: {
            'Save to rdft': function() {
			{
			
			if (selectedElementId !== 0) {
            var cell = graph.getCell(selectedElementId);
			var type = cell.get('type');

                cell.attr('.selectionFrame/display', 'none');
        }

        selectedElementId = 0;
        
		var elements = graph.getElements();
		var links = graph.getLinks();
		
		var oval = [];
		var square = [];
		var blank = [];
		var link = [];
		
		_.each(elements, function (elem) {
            var type = elem.get('type');
			switch(type)
			{
				case 'rdf.OvalObject':
				{
					 oval.push(elem);
				}
				break;
				case 'rdf.SquereObject':
				{
					 square.push(elem);
				}
				break;
				case 'rdf.BlankObject':
				{
					 blank.push(elem);
				}
				break;
			}
		});
		
		_.each(links, function (elem) {
            var type = elem.get('type');
			link.push(elem);
		});
		
		outputRDFContent = JSON.stringify(oval) + '\n';
		outputRDFContent += JSON.stringify(square) + '\n';
		outputRDFContent += JSON.stringify(blank) + '\n';
		outputRDFContent += JSON.stringify(link) + '\n';
		
		var textArea = document.createElement('textarea');
        textArea.value = outputRDFContent;
        if (textArea.value != '') {
            var blob = new Blob([textArea.value], { type: "text/plain;charset=" + document.characterSet });
            saveAs(blob, $("#text_filename").val() + '.rdft');
        }
			}
                $(this).dialog("close");

            },
			'Export to RDF/XML': function() {
			
			var links = graph.getLinks();
			var triplets = '';
        _.each(links, function (link) {
		
			var singleTriplet = '';
			var src = graph.getCell(link.get('source').id);
			var dst = graph.getCell(link.get('target').id);
			
			switch(src.get('type'))
			{
				case 'rdf.OvalObject': 
				{
					singleTriplet += '<' + src.attr('.text_value/text') + '> ';
				}
				break;
				case 'rdf.BlankObject': 
				{
					singleTriplet += src.attr('.text_value/text') + ' ';
				}
				break;
			}
			singleTriplet += '<' + link.get('labels')[0]['attrs']['text']['text'] + '> ';
			
			switch(dst.get('type'))
			{
				case 'rdf.OvalObject': 
				{
					singleTriplet += '<' + dst.attr('.text_value/text') + '> .';
				}
				break;
				case 'rdf.BlankObject': 
				{
					singleTriplet += dst.attr('.text_value/text') + ' .';
				}
				break;
				case 'rdf.SquereObject': 
				{
					singleTriplet += '"' + dst.attr('.text_value/text') + '"';
					if(dst.get('rdftype') === '')
					{
						singleTriplet += ' .';
					}
					else
					{
						singleTriplet += '^^<' + dst.get('rdftype') + '> .';
					}
				}
				break;
			}
			triplets += singleTriplet + '\n';
			
		});
			$("#triplesData").val(triplets);
			$("#submitTriples").click();
			
                $(this).dialog("close");

            },
			'Cancel': function() {
				//alert($("#someText").val());
                $(this).dialog("close");

            }
        }
    });

});